# 🌐 `@geo watch`

watch the planet's [story](./targets.yaml) unfold

```bash
@geo watch help
```
--help-- blue_geo watch

## example run

```bash
@batch eval - \
  blue_geo watch - \
  target=chilcotin-river-landslide \
  to=aws_batch - \
  publish \
  geo-watch-2024-09-01-chilcotin-a
```

--table--
